@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2015
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2024
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -23,11 +24,11 @@ namespace polymake { namespace topaz {
 using graph::Lattice;
 using graph::lattice::BasicDecoration;
 
-Array< Set<int> > facets_from_hasse_diagram(perl::Object p)
+Array<Set<Int>> facets_from_hasse_diagram(BigObject p)
 {
    const Lattice<BasicDecoration> HD(p);
-   Array< Set<int> > F( attach_member_accessor( select(HD.decoration(), HD.in_adjacent_nodes(HD.top_node())),
-               ptr2type<BasicDecoration, Set<int>,&BasicDecoration::face>()
+   Array<Set<Int>> F( attach_member_accessor( select(HD.decoration(), HD.in_adjacent_nodes(HD.top_node())),
+               ptr2type<BasicDecoration, Set<Int>, &BasicDecoration::face>()
                ));
    return F;
 }
